@@ -146,9 +146,6 @@ def upload(url,filename,bearer):
 upload(url,'fullauto.pem',bearer)
 
 time.sleep( 1 )
-print "SENDING"
-print "DUH"
-#print new_inst
 
 data = {'cmd': [['cmd','mv /tmp/fullauto.pem /home/Administrator/FullAutoAPI'],
                 ['cwd','/home/Administrator/FullAutoAPI'],
@@ -201,8 +198,7 @@ print '==================='
 print docker_ip
 data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':'fullauto.pem','noretry':'1'}]]}
 time.sleep( 1 )
-print "SENDING"
-#data = {'cmd': [['cmd','pwd']]}
+docker_server1='';
 while loop == 1: # This creates an infinite loop
    print "GOING FOR CONNECT"
    headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
@@ -213,6 +209,57 @@ while loop == 1: # This creates an infinite loop
       time.sleep( 1 )
       continue
    else:
-      print result[0][0]
+      print "GOT DOCKER!!!!"
+      docker_server1=result[0][0]
    break
+time.sleep( 1 )
+print "DOCKER_SERVER1="+docker_server1
+data = {'cmd': [['label',[docker_server1,'cmd','sudo yum -y install docker docker-registry']],
+                ['label',[docker_server1,'cmd','sudo service docker start']],
+                ['label',[docker_server1,'cmd','sudo usermod -a -G docker ec2-user']]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+print "LABEL_RESULT="+str(result[0][0])
+time.sleep( 1 )
+data = {'cmd': [['label',[docker_server1,'close']]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+print "LABEL_RESULT="+str(result)
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':'fullauto.pem','noretry':'1'}]]}
+time.sleep( 1 )
+docker_server1='';
+while loop == 1: # This creates an infinite loop
+   print "GOING FOR CONNECT"
+   headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+   result = json.loads(content)
+   result = json.loads(result['result'])
+   if re.search('Connection timed out|Connection refused',result[0][1]):
+      print result[0][1]
+      time.sleep( 1 )
+      continue
+   else:
+      print "GOT DOCKER AGAIN!!!!"
+      docker_server1=result[0][0]
+   break
+time.sleep( 1 )
+print "DOCKER_SERVER1="+docker_server1
+data = {'cmd': [['label',[docker_server1,'cmd','hostname']]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+print "HOSTNAME="+str(result[0][0])
+time.sleep( 1 )
+data = {'cmd': [['label',[docker_server1,'cmd','docker info']]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+print "DOCKER INFO="+str(result[0][0])
+time.sleep( 1 )
+data = {'cmd': [['label',[docker_server1,'docker_run','ubuntu /bin/bash']]]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+print "DOCKER CONTAINER HOSTNAME="+str(result[0][0])
 
